@@ -3,7 +3,8 @@ import os
 
 
 class Options(object):
-    service = ''
+    service = None
+    service_name = None
     agent_host = ''
     agent_port = 0
     log_level = logging.WARN
@@ -12,9 +13,12 @@ class Options(object):
         """ Initialize Options
         Respect any environment variables that may be set.
         """
-        if "INSTANA_DEV" in os.environ:
+        if "INSTANA_DEBUG" in os.environ:
             self.log_level = logging.DEBUG
 
+        if "INSTANA_SERVICE_NAME" in os.environ:
+            self.service_name = os.environ["INSTANA_SERVICE_NAME"]
+
         if "INSTANA_AGENT_IP" in os.environ:
             # Deprecated: INSTANA_AGENT_IP environment variable
             # To be removed in a future version
